##  SAP LeanIX Products
SAP LeanIX comprises three products supporting different enterprise architecture domains and use cases.
  * SAP LeanIX Application Portfolio Management: The base product for documenting and managing your application landscape. It provides insights into application lifecycles, dependencies, technical and functional fit, and business impact. Primarily, it drives the use cases of [Application Portfolio Assessment](https://help.sap.com/docs/leanix/ea/application-portfolio-assessment?locale=en-US&state=PRODUCTION&version=CLOUD "Establish transparency and governance over your as-is landscape to identify optimization opportunities and unlock further use cases.") and [Application Rationalization](https://help.sap.com/docs/leanix/ea/application-rationalization?locale=en-US&state=PRODUCTION&version=CLOUD "Application rationalization reduces costs, eliminates redundancies, and improves efficiency. Optimize your application landscape with this step-by-step approach.") by helping you identify redundancies and optimize technology investments.
  * SAP LeanIX Architecture and Road Map Planning: An additional product that compliments SAP LeanIX Application Portfolio Management. It offers advanced features to plan target architecture, visualize the impacts of the planned transformations, and implement and monitor transformation initiatives. It drives the use cases of [Application Modernization](https://help.sap.com/docs/leanix/ea/application-modernization?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX offers a strategic approach to modernizing outdated application portfolios, helping organizations reduce technical debt and operational costs while enhancing agility and innovation. This guide is useful for understanding how to effectively plan and execute continuous transformation tailored to specific organizational needs.") and [ERP Transformation](https://help.sap.com/docs/leanix/ea/erp-transformation?locale=en-US&state=PRODUCTION&version=CLOUD "Step-by-step guide for ERP Transformation using SAP LeanIX."). Learn more in [SAP LeanIX Architecture and Road Map Planning](https://help.sap.com/docs/leanix/ea/sap-leanix-architecture-and-road-map-planning?locale=en-US&state=PRODUCTION&version=CLOUD "The SAP LeanIX Architecture and Road Map Planning enhances SAP LeanIX Application Portfolio Management by offering advanced features for seamless planning and execution of transformation initiatives in enterprise architecture management.").
  * SAP LeanIX Technology Risk and Compliance: This product extends the capabilities of SAP LeanIX Application Portfolio Management. It facilitates the discovery of the infrastructure layer in your application landscape and enables you to manage obsolescence risks and technology standards. This ensures operational stability and relevance of your technology stack. It drives the use case of [obsolescence risk management](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management?locale=en-US&state=PRODUCTION&version=CLOUD "Learn why obsolescence risk management matters, how to discover risks associated with obsolete technology, how to assess their business impact, and how to efficiently manage and address them with SAP LeanIX.") and technology standards management. Learn more in [SAP LeanIX Technology Risk and Compliance](https://help.sap.com/docs/leanix/ea/sap-leanix-technology-risk-and-compliance?locale=en-US&state=PRODUCTION&version=CLOUD "Get an overview of SAP LeanIX Technology Risk and Compliance, with links to detailed guides for managing obsolescence risk, optimizing technology usage, and enforcing tech standards across your IT landscape.").
